@@ -1,9 +1,10 @@
 from ..cache import get_cache_key, get_hexdigest, get_hashed_mtime
 from ..settings import COFFEESCRIPT_EXECUTABLE, COFFEESCRIPT_USE_CACHE,\
-    COFFEESCRIPT_CACHE_TIMEOUT, COFFEESCRIPT_OUTPUT_DIR
+    COFFEESCRIPT_CACHE_TIMEOUT, COFFEESCRIPT_OUTPUT_DIR, POSIX_COMPATIBLE
 from django.conf import settings
 from django.core.cache import cache
 from django.template.base import Library, Node
+from os.path import join, dirname, exists, basename
 import logging
 import shlex
 import subprocess
@@ -20,7 +21,7 @@ class InlineCoffeescriptNode(Node):
         self.nodelist = nodelist
 
     def compile(self, source):
-        args = shlex.split("%s -c -s -p" % COFFEESCRIPT_EXECUTABLE)
+        args = shlex.split("%s -c -s -p" % COFFEESCRIPT_EXECUTABLE, posix=POSIX_COMPATIBLE)
 
         p = subprocess.Popen(args, stdin=subprocess.PIPE, stdout=subprocess.PIPE)
         out, errors = p.communicate(source.encode("utf-8"))
@@ -53,51 +54,75 @@ def do_inlinecoffeescript(parser, token):
     return InlineCoffeescriptNode(nodelist)
 
 
-@register.simple_tag
-def coffeescript(path):
+def coffeescript_paths(path):
 
     try:
-        STATIC_ROOT = settings.STATIC_ROOT
+        root = settings.STATIC_ROOT
     except AttributeError:
-        STATIC_ROOT = settings.MEDIA_ROOT
+        root = settings.MEDIA_ROOT
 
-    full_path = os.path.join(STATIC_ROOT, path)
-    filename = os.path.split(path)[-1]
-
-    output_directory = os.path.join(STATIC_ROOT, COFFEESCRIPT_OUTPUT_DIR, os.path.dirname(path))
+    # while developing it is more confortable
+    # searching for the coffeescripts rather then 
+    # doing collectstatics all the time
+    if settings.DEBUG:
+        for sfdir in settings.STATICFILES_DIRS:
+            prefix = None
+            if isinstance(sfdir, (tuple, list)):
+                prefix, sfdir = sfdir
+            if prefix:
+                if not path.startswith(prefix):
+                    continue
+                input_file = join(sfdir, path[len(prefix):].lstrip(os.sep))
+            else:
+                input_file = join(sfdir, path)
+            if exists(input_file):
+                output_dir = join(root, COFFEESCRIPT_OUTPUT_DIR, dirname(path))
+                file_name = basename(path)
+                return input_file, file_name, output_dir
+    
+    full_path = os.path.join(root, path)
+    file_name = os.path.split(path)[-1]
+    
+    output_dir = os.path.join(root, COFFEESCRIPT_OUTPUT_DIR, os.path.dirname(path))
+    
+    return full_path, file_name, output_dir
 
+@register.simple_tag
+def coffeescript(path):
+    logger.info("processing file %s" % path)
+    
+    full_path, file_name, output_dir = coffeescript_paths(path)
+    
     hashed_mtime = get_hashed_mtime(full_path)
 
-    if filename.endswith(".coffee"):
-        base_filename = filename[:-7]
-    else:
-        base_filename = filename
+    base_file_name = file_name.replace(".coffee","")
 
-    output_path = os.path.join(output_directory, "%s-%s.js" % (base_filename, hashed_mtime))
+    output_file = "%s-%s.js" % (base_file_name, hashed_mtime)
+    output_path = os.path.join(output_dir, output_file)
 
     if not os.path.exists(output_path):
         source_file = open(full_path)
         source = source_file.read()
         source_file.close()
 
-        args = shlex.split("%s -c -s -p" % COFFEESCRIPT_EXECUTABLE)
+        args = shlex.split("%s -c -s -p" % COFFEESCRIPT_EXECUTABLE, posix=POSIX_COMPATIBLE)
         p = subprocess.Popen(args, stdin=subprocess.PIPE,
                              stdout=subprocess.PIPE, stderr=subprocess.PIPE)
         out, errors = p.communicate(source)
         if out:
-            if not os.path.exists(output_directory):
-                os.makedirs(output_directory)
+            if not os.path.exists(output_dir):
+                os.makedirs(output_dir)
             compiled_file = open(output_path, "w+")
             compiled_file.write(out)
             compiled_file.close()
 
             # Remove old files
             compiled_filename = os.path.split(output_path)[-1]
-            for filename in os.listdir(output_directory):
-                if filename.startswith(base_filename) and filename != compiled_filename:
-                    os.remove(os.path.join(output_directory, filename))
+            for filename in os.listdir(output_dir):
+                if filename.startswith(base_file_name) and filename != compiled_filename:
+                    os.remove(os.path.join(output_dir, filename))
         elif errors:
             logger.error(errors)
             return path
 
-    return output_path[len(STATIC_ROOT):].replace(os.sep, '/').lstrip("/")
+    return join(COFFEESCRIPT_OUTPUT_DIR, dirname(path), output_file)
